@@ -9,6 +9,6 @@ class SoftDeleteCascadeMixin(safedelete_models.SafeDeleteModel):
     _safedelete_policy = safedelete_models.SOFT_DELETE_CASCADE
 
     @staticmethod
-    def get_unique_constraint(fields):
-        return UniqueConstraint(fields=cls.UNIQUE_FIELDS, condition=Q(deleted__isnull=True),
-                                name='unique_active_{}'.format('_'.join(fields)))
+    def get_unique_constraint(model_name, fields):
+        return [UniqueConstraint(fields=fields, condition=Q(deleted__isnull=True),
+                                 name='unique_active_{},{}'.format(model_name, '_'.join(fields)))]
