@@ -1,5 +1,5 @@
 from oauth2_provider.views.mixins import ProtectedResourceMixin, OAuthLibMixin
-from .base import method_decorator, csrf_exempt, view_catch_error, BaseCrudView, BaseView
+from .base import method_decorator, csrf_exempt, view_catch_error, BaseCrudView, BaseView, unjsonize
 from .lookups import ChoicesView
 
 
@@ -20,7 +20,8 @@ class _SetUserCrudView(BaseCrudView):
 
     def post(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).post(
-            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+            body=unjsonize(request.body.decode()), request=request,
+            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def post_file(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).post_file(
@@ -29,7 +30,8 @@ class _SetUserCrudView(BaseCrudView):
 
     def put(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).put(
-            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+            body=unjsonize(request.body.decode()), request=request,
+            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def delete(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).delete(
